@@ -537,7 +537,7 @@ void update()
 	curTime = time(0);
 
 	if ( curTime != last_time ) {
-		if ((curTime - last_time) >= state.update_interval) {
+		if ( abs(curTime - last_time) >= state.update_interval) {
 			last_time = curTime;
 			refresh();
 		}
