@@ -8,8 +8,8 @@
  * This software is distributed under GPL. For details see LICENSE file.
  */
 
-#ifndef _ascpu_x_h_
-#define _ascpu_x_h_
+#ifndef _astime_x_h_
+#define _astime_x_h_
 
 void initialize(int argc, char **argv,
                 char *window_name,
