@@ -29,9 +29,9 @@ Pixel GetColor(char *ColorName, Display * disp, Window win)
 	Color.pixel = 0;
 
 	if (!XParseColor(disp, Attributes.colormap, ColorName, &Color))
-		printf("asapm: can't parse %s\n", ColorName);
+		printf("astime: can't parse %s\n", ColorName);
 	else if (!XAllocColor(disp, Attributes.colormap, &Color))
-		printf("asapm: can't allocate %s\n", ColorName);
+		printf("astime: can't allocate %s\n", ColorName);
 
 	return Color.pixel;
 }
@@ -49,9 +49,9 @@ XColor ParseColor(char *ColorName, Display * disp, Window win)
 	Color.pixel = 0;
 
 	if (!XParseColor(disp, Attributes.colormap, ColorName, &Color))
-		printf("asapm: can't parse %s\n", ColorName);
+		printf("astime: can't parse %s\n", ColorName);
 	else if (!XAllocColor(disp, Attributes.colormap, &Color))
-		printf("asapm: can't allocate %s\n", ColorName);
+		printf("astime: can't allocate %s\n", ColorName);
 
 	return Color;
 }
